%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initializations
Fs = 11025;  % Number of samples per second (sample frequency)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Design a low-pass filter with a cutoff frequency of 2.5 kHz
[N,Fo,Ao,W] = firpmord([2500, 2800], [1 0], [0.01 0.001], Fs);
h_lowpass   = firpm(N,Fo,Ao,W);

% Plot the implulse response of the filter
figure(1);clf;
plot(h_lowpass);
pause

% Plot the magnitude-phase response of the low-pass filter
figure(2);clf;
freqz(h_lowpass,1,[],Fs);
pause
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load the WAVE file with the Harvard Phrases
VoiceSignal = wavread('HarvardPhrases.wav');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Filter the voice signal
FilteredVoiceSignal = filter(h_lowpass,1,VoiceSignal);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot both of the voice signals in their entireity
t_entire = [0:length(VoiceSignal)-1]'/Fs;
figure(3);clf;

subplot(211)
plot(t_entire,VoiceSignal);

subplot(212)
plot(t_entire,FilteredVoiceSignal);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the Fourier Transform of the two voice signals and plot them
FFT_VoiceSignal  = fft(VoiceSignal)/Fs;
FFT_FilteredVoiceSignal  = fft(FilteredVoiceSignal)/Fs;

% The first value in the FFT has a frequency of zero (DC), the last value in FFT
% has a frequency of Fs-1.  The only problem is we have length(VoiceSignal)
% points in the FFT, so let's just divide out length(VoiceSignal) and multiply
% in Fs;
f = Fs/length(VoiceSignal)*[0:length(VoiceSignal)-1]';

% We only care to plot the frequencies below Fs/2 kHz
fMax = Fs/2;
idx = find(f < fMax);

figure(4);clf;

subplot(211)
plot(f(idx),20*log10(abs(FFT_VoiceSignal(idx))));
axis([0, fMax, -90, -10]);

subplot(212)
plot(f(idx),20*log10(abs(FFT_FilteredVoiceSignal(idx))));
axis([0, fMax, -90, -10]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Play the VoiceSignal
sound(VoiceSignal,Fs);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Play the FilteredVoiceSignal
sound(FilteredVoiceSignal,Fs);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
