%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initializations
Fs = 11025;  % Number of samples per second (sample frequency)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate some DTMF tones for 8-6-5-7-3-0-9

% This table is copied from Wikipedia
%DTMF keypad frequencies (with sound clips)
%           1209 Hz 1336 Hz 1477 Hz 1633 Hz
%  697 Hz     1       2       3       A
%  770 Hz     4       5       6       B
%  852 Hz     7       8       9       C
%  941 Hz     *       0       #       D
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
t     = [0:Fs-1]'/Fs;   % This is one second of time
A     = 10^(-20/20);    % Amplitude of the tones
Twist = 10^(3/20);      % The high tone is this much louder than the low tone
LongTone=[];

% Tone for 8
f1 = 852;
f2 = 1336;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];

% Tone for 6
f1 = 770;
f2 = 1477;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];

% Tone for 7
f1 = 852;
f2 = 1209;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];

% Tone for 5
f1 = 770;
f2 = 1336;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];

% Tone for 3
f1 = 697;
f2 = 1477;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];

% Tone for 0
f1 = 941;
f2 = 1336;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];

% Tone for 9
f1 = 852;
f2 = 1477;
ThisTone = A*( cos(2*pi*f1*t) + Twist*cos(2*pi*f2*t) );
LongTone = [LongTone;ThisTone];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load the WAVE file with the Harvard Phrases
VoiceSignal = wavread('HarvardPhrases.wav');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Form the three signals
ToneSignal = zeros(size(VoiceSignal));
ToneSignal(1*Fs + [1:length(LongTone)]) = LongTone;
OutputSignal = ToneSignal + VoiceSignal;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the entire voice signal
t_entire = [0:length(VoiceSignal)-1]'/Fs;
figure(1);clf;
plot(t_entire,VoiceSignal);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the 2nd second of each of the three signals
figure(2);clf

subplot(311)
plot(1+t,VoiceSignal(Fs+[1:Fs]));
axis([1, 2, -1, 1])

subplot(312)
plot(1+t,ToneSignal(Fs+[1:Fs]));
axis([1, 2, -1, 1])

subplot(313)
plot(1+t,OutputSignal(Fs+[1:Fs]));
axis([1, 2, -1, 1])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the Fourier Transform of the three signals and plot them
FFT_VoiceSignal  = fft(VoiceSignal)/Fs;
FFT_ToneSignal   = fft(ToneSignal)/Fs;
FFT_OutputSignal = fft(OutputSignal)/Fs;

% The first value in the FFT has a frequency of zero (DC), the last value in FFT
% has a frequency of Fs-1.  The only problem is we have length(VoiceSignal)
% points in the FFT, so let's just divide out length(VoiceSignal) and multiply
% in Fs;
f = Fs/length(VoiceSignal)*[0:length(VoiceSignal)-1]';

% We only care to plot the frequencies below Fs/2 kHz
fMax = Fs/2;
idx = find(f < fMax);

figure(3);clf

subplot(311)
plot(f(idx),20*log10(abs(FFT_VoiceSignal(idx))));
axis([0, fMax, -90, -10]);

subplot(312)
plot(f(idx),20*log10(abs(FFT_ToneSignal(idx))));
axis([0, fMax, -90, -10]);

subplot(313)
plot(f(idx),20*log10(abs(FFT_OutputSignal(idx))));
axis([0, fMax, -90, -10]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Play the OutputSignal
sound(OutputSignal,Fs);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
