%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initializations
Fs  = 11025;  % Number of samples per second (sample frequency)
Fs1 = Fs/2;   % half the original sample frequency
Fs2 = Fs*2;   % twice the original sample frequency
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load the WAVE file with the Harvard Phrases
VoiceSignal = wavread('HarvardPhrases.wav');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the three voice signals in their entireity
t_entire  = [0:length(VoiceSignal)-1]'/Fs;
t_entire1 = [0:length(VoiceSignal)-1]'/Fs1;
t_entire2 = [0:length(VoiceSignal)-1]'/Fs2;
figure(1);clf;

subplot(311)
plot(t_entire,VoiceSignal);

subplot(312)
plot(t_entire1,VoiceSignal);

subplot(313)
plot(t_entire2,VoiceSignal);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the Fourier Transform of the voice signal and plot it three times
FFT_VoiceSignal  = fft(VoiceSignal)/Fs;

% The first value in the FFT has a frequency of zero (DC), the last value in FFT
% has a frequency of Fs-1.  The only problem is we have length(VoiceSignal)
% points in the FFT, so let's just divide out length(VoiceSignal) and multiply
% in Fs;
f  = Fs/length(VoiceSignal)*[0:length(VoiceSignal)-1]';
f1 = Fs1/length(VoiceSignal)*[0:length(VoiceSignal)-1]';
f2 = Fs2/length(VoiceSignal)*[0:length(VoiceSignal)-1]';

% We only care to plot the frequencies below Fs/2 kHz
fMax  = Fs/2;
fMax1 = Fs1/2;
fMax2 = Fs2/2;
idx  = find(f  < fMax);
idx1 = find(f1 < fMax1);
idx2 = find(f2 < fMax2);

figure(2);clf;

subplot(311)
plot(f(idx),20*log10(abs(FFT_VoiceSignal(idx))));
axis([0, fMax2, -90, -10]);

subplot(312)
plot(f1(idx1),20*log10(abs(FFT_VoiceSignal(idx1))));
axis([0, fMax2, -90, -10]);

subplot(313)
plot(f2(idx2),20*log10(abs(FFT_VoiceSignal(idx2))));
axis([0, fMax2, -90, -10]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Play the VoiceSignal at Fs
sound(VoiceSignal,Fs);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Play the VoiceSignal at Fs1
sound(VoiceSignal,Fs1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
pause


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Play the VoiceSignal at Fs2
sound(VoiceSignal,Fs2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
